# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKFastMarchingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkFastMarchingImageFilterBasePython
else:
    import _itkFastMarchingImageFilterBasePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkSizePython
import itk.itkPointPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.ITKFastMarchingBasePython
import itk.itkNodePairPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterCommonPython
import itk.itkLevelSetNodePython
import itk.itkFastMarchingStoppingCriterionBasePython

def itkFastMarchingImageFilterBaseIF2IF2_New():
    return itkFastMarchingImageFilterBaseIF2IF2.New()

class itkFastMarchingImageFilterBaseIF2IF2(itk.ITKFastMarchingBasePython.itkFastMarchingBaseIF2IF2):
    r"""Proxy of C++ itkFastMarchingImageFilterBaseIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingImageFilterBaseIF2IF2_Pointer"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingImageFilterBaseIF2IF2_Pointer"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_Clone(self)

    def GetModifiableLabelImage(self):
        r"""GetModifiableLabelImage(self) -> itkImageUC2"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetModifiableLabelImage(self)

    def GetLabelImage(self, *args):
        r"""
        GetLabelImage(self) -> itkImageUC2
        GetLabelImage(self) -> itkImageUC2
        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetLabelImage(self, *args)

    def SetOutputSize(self, size):
        r"""
        SetOutputSize(self, size)

        Parameters
        ----------
        size: itkSize2 const &

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_SetOutputSize(self, size)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize2"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetOutputSize(self)

    def SetOutputRegion(self, _arg):
        r"""
        SetOutputRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion2

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_SetOutputRegion(self, _arg)

    def GetOutputRegion(self):
        r"""GetOutputRegion(self) -> itkImageRegion2"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetOutputRegion(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD2

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD2"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetOutputSpacing(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD22

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD22"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetOutputDirection(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD2

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD2"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetOutputOrigin(self)

    def SetOverrideOutputInformation(self, _arg):
        r"""
        SetOverrideOutputInformation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_SetOverrideOutputInformation(self, _arg)

    def GetOverrideOutputInformation(self):
        r"""GetOverrideOutputInformation(self) -> bool const &"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_GetOverrideOutputInformation(self)

    def OverrideOutputInformationOn(self):
        r"""OverrideOutputInformationOn(self)"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_OverrideOutputInformationOn(self)

    def OverrideOutputInformationOff(self):
        r"""OverrideOutputInformationOff(self)"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_OverrideOutputInformationOff(self)
    __swig_destroy__ = _itkFastMarchingImageFilterBasePython.delete_itkFastMarchingImageFilterBaseIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingImageFilterBaseIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingImageFilterBaseIF2IF2

        Create a new object of the class itkFastMarchingImageFilterBaseIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingImageFilterBaseIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingImageFilterBaseIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingImageFilterBaseIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingImageFilterBaseIF2IF2 in _itkFastMarchingImageFilterBasePython:
_itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF2IF2_swigregister(itkFastMarchingImageFilterBaseIF2IF2)

def itkFastMarchingImageFilterBaseIF3IF3_New():
    return itkFastMarchingImageFilterBaseIF3IF3.New()

class itkFastMarchingImageFilterBaseIF3IF3(itk.ITKFastMarchingBasePython.itkFastMarchingBaseIF3IF3):
    r"""Proxy of C++ itkFastMarchingImageFilterBaseIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFastMarchingImageFilterBaseIF3IF3_Pointer"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFastMarchingImageFilterBaseIF3IF3_Pointer"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_Clone(self)

    def GetModifiableLabelImage(self):
        r"""GetModifiableLabelImage(self) -> itkImageUC3"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetModifiableLabelImage(self)

    def GetLabelImage(self, *args):
        r"""
        GetLabelImage(self) -> itkImageUC3
        GetLabelImage(self) -> itkImageUC3
        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetLabelImage(self, *args)

    def SetOutputSize(self, size):
        r"""
        SetOutputSize(self, size)

        Parameters
        ----------
        size: itkSize3 const &

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_SetOutputSize(self, size)

    def GetOutputSize(self):
        r"""GetOutputSize(self) -> itkSize3"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetOutputSize(self)

    def SetOutputRegion(self, _arg):
        r"""
        SetOutputRegion(self, _arg)

        Parameters
        ----------
        _arg: itkImageRegion3

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_SetOutputRegion(self, _arg)

    def GetOutputRegion(self):
        r"""GetOutputRegion(self) -> itkImageRegion3"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetOutputRegion(self)

    def SetOutputSpacing(self, _arg):
        r"""
        SetOutputSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_SetOutputSpacing(self, _arg)

    def GetOutputSpacing(self):
        r"""GetOutputSpacing(self) -> itkVectorD3"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetOutputSpacing(self)

    def SetOutputDirection(self, _arg):
        r"""
        SetOutputDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_SetOutputDirection(self, _arg)

    def GetOutputDirection(self):
        r"""GetOutputDirection(self) -> itkMatrixD33"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetOutputDirection(self)

    def SetOutputOrigin(self, _arg):
        r"""
        SetOutputOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_SetOutputOrigin(self, _arg)

    def GetOutputOrigin(self):
        r"""GetOutputOrigin(self) -> itkPointD3"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetOutputOrigin(self)

    def SetOverrideOutputInformation(self, _arg):
        r"""
        SetOverrideOutputInformation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_SetOverrideOutputInformation(self, _arg)

    def GetOverrideOutputInformation(self):
        r"""GetOverrideOutputInformation(self) -> bool const &"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_GetOverrideOutputInformation(self)

    def OverrideOutputInformationOn(self):
        r"""OverrideOutputInformationOn(self)"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_OverrideOutputInformationOn(self)

    def OverrideOutputInformationOff(self):
        r"""OverrideOutputInformationOff(self)"""
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_OverrideOutputInformationOff(self)
    __swig_destroy__ = _itkFastMarchingImageFilterBasePython.delete_itkFastMarchingImageFilterBaseIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFastMarchingImageFilterBaseIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFastMarchingImageFilterBaseIF3IF3

        Create a new object of the class itkFastMarchingImageFilterBaseIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFastMarchingImageFilterBaseIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFastMarchingImageFilterBaseIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFastMarchingImageFilterBaseIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFastMarchingImageFilterBaseIF3IF3 in _itkFastMarchingImageFilterBasePython:
_itkFastMarchingImageFilterBasePython.itkFastMarchingImageFilterBaseIF3IF3_swigregister(itkFastMarchingImageFilterBaseIF3IF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def fast_marching_image_filter_base(*args: itkt.ImageLike,  output_size: Sequence[int]=..., output_region: itkt.ImageRegion=..., output_spacing: Sequence[float]=..., output_direction=..., output_origin: Sequence[float]=..., override_output_information: bool=..., topology_check=..., trial_points=..., alive_points=..., processed_points=..., forbidden_points=..., stopping_criterion=..., speed_constant: float=..., normalization_factor: float=..., collect_points: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for FastMarchingImageFilterBase"""
    import itk

    kwarg_typehints = { 'output_size':output_size,'output_region':output_region,'output_spacing':output_spacing,'output_direction':output_direction,'output_origin':output_origin,'override_output_information':override_output_information,'topology_check':topology_check,'trial_points':trial_points,'alive_points':alive_points,'processed_points':processed_points,'forbidden_points':forbidden_points,'stopping_criterion':stopping_criterion,'speed_constant':speed_constant,'normalization_factor':normalization_factor,'collect_points':collect_points }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.FastMarchingImageFilterBase.New(*args, **kwargs)

    return instance.__internal_call__()

def fast_marching_image_filter_base_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKFastMarching.FastMarchingImageFilterBase
    fast_marching_image_filter_base.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    fast_marching_image_filter_base.__doc__ = filter_object.__doc__



